@@ -1,6 +1,7 @@
 package AnyEvent::Impl::Perl;
 
 no warnings;
+use strict;
 
 use Time::HiRes qw(time);
 use Scalar::Util ();
@@ -109,20 +110,5 @@ sub DESTROY {
    %$self = ();
 }
 
-sub condvar {
-   my $class = shift;
-
-   bless \my $flag, $class
-}
-
-sub broadcast {
-   ${$_[0]}++;
-}
-
-sub wait {
-   one_event while !${$_[0]};
-}
-
-
 1
 
